Crate yagbas_asttypes

Crate yagbas_asttypes 

Re-exports

pub use super::*;

Structs

Ast
The Abstract Syntax Tree for the whole program.
BitStruct
Bitpacked structured data.
Const
Constant definition
Func
Function definition
IfElse
Branching construct.
Loop
Repeating code construct.
S
Generic typed value paired with a SimpleSpan
Static
Static definition
Struct
Structured data.

Enums

AstParseError
Expr
An expression is a thing that can be made of sub-expressions.
Item
An item is basically “a top level definition within a source file”.
Register
The registers that can be named anywhere in any expression.
Statement
Any of the things that can go in a body of code.

Functions

items_of
make_tt_input
Makes a token tree slice into an Input.