Skip to main contentCrate yagbas_asttypes
Source pub use super::*;
- Ast
- The Abstract Syntax Tree for the whole program.
- BitStruct
- Bitpacked structured data.
- Const
- Constant definition
- Func
- Function definition
- IfElse
- Branching construct.
- Loop
- Repeating code construct.
- S
- Generic typed value paired with a
SimpleSpan - Static
- Static definition
- Struct
- Structured data.
- AstParseError
- Expr
- An expression is a thing that can be made of sub-expressions.
- Item
- An item is basically “a top level definition within a source file”.
- Register
- The registers that can be named anywhere in any expression.
- Statement
- Any of the things that can go in a body of code.
- items_of
- make_tt_input
- Makes a token tree slice into an Input.